#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ENUMERATE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ENUMERATE_HPP_INCLUDED

#include <boost/simd/swar/include/functions/enumerate.hpp>

#endif
